@@ -22,6 +22,8 @@ class ClientModel(ABC):
             self.author = author
         if not ignored_list:
             self.ignored_list = []
+        else:
+            self.ignored_list = ignored_list
         self.__setitem__('author', self.author)
         self.plugin_version = plugin_version
         self.__setitem__('plugin_version', self.plugin_version)
@@ -42,11 +44,12 @@ class ClientModel(ABC):
                             self.__setitem__(key, _dict[key])
         elif _dict:
             self.dict.update(_dict)
-        for key in ignored_list:
-            try:
-                self.__delitem__(key)
-            except KeyError:
-                pass
+        if len(self.ignored_list) > 0:
+            for key in self.ignored_list:
+                try:
+                    self.__delitem__(key)
+                except KeyError:
+                    pass
         self.validate()
 
     def __getitem__(self, key):
